function varargout = nlevp(name,varargin)
%NLEVP   Collection of nonlinear eigenvalue problems.
%  [OUT1,OUT2,...] = NLEVP(NAME, ARG1, ARG2,...)
%    generates the matrices defining the problem specified by NAME (a string).
%    ARG1, ARG2,... are input arguments and OUT1, OUT2, ...
%    are the output arguments.  See the list below for the available problems.
%
%  PROBLEMS = NLEVP('query','problems') or NLEVP QUERY PROBLEMS
%    returns a cell array containing the names of all problems
%    in the collection.
%  NLEVP('help','name') or NLEVP HELP NAME
%    gives additional information on problem NAME, including number and
%    meaning of input/output arguments.
%  NLEVP('query','name') or NLEVP QUERY NAME
%    returns a cell array containing the properties of the problem NAME.
%  PROPERTIES = NLEVP('query','properties') or NLEVP QUERY PROPERTIES
%    returns the properties used to classify problems in the collection.
%  NLEVP('query',PROPERTY1,PROPERTY2,...) or NLEVP QUERY PROPERTY1 ...
%    lists the names of all problems having the specified properties.
%
%  Available problems:
%
%  acoustic_wave_1d   Acoustic wave problem in 1 dimension.
%  acoustic_wave_2d   Acoustic wave problem in 2 dimensions.
%  bicycle            2-by-2 QEP from the Whipple bicycle model.
%  bilby              5-by-5 QEP from Bilby population model.
%  butterfly          Quartic matrix polynomial with T-even structure.
%  cd_player          QEP from model of CD player.
%  closed_loop        2-by-2 QEP associated with closed-loop control system.
%  concrete           Sparse QEP from model of a concrete structure.
%  damped_beam        QEP from simply supported beam damped in the middle.
%  dirac              QEP from Dirac operator.
%  gun                NEP from model of a radio-frequency gun cavity.
%  hospital           QEP from model of Los Angeles Hospital building.
%  loaded_string      REP from finite element model of a loaded vibrating
%                     string.
%  mobile_manipulator QEP from model of 2-dimensional 3-link mobile manipulator.
%  orr_sommerfeld     Quartic PEP arising from Orr-Sommerfeld equation.
%  power_plant        8-by-8 QEP from simplified nuclear power plant problem.
%  railtrack          QEP from study of vibration of rail tracks.
%  schrodinger        QEP from Schrodinger operator.
%  sign1              QEP from rank-1 perturbation of sign operator.
%  sign2              QEP from rank-1 perturbation of 2*sin(x) + sign(x)
%                     operator.
%  sleeper            QEP modelling a railtrack resting on sleepers.
%  spring_dashpot     QEP from model of spring/dashpot configuration.
%  string             QEP from finite element model of vibrating string.
%  wing               QEP from analysis of oscillations of a wing in an
%                     airstream.
%  wiresaw1           Gyroscopic system from the vibration analysis of wiresaw.
%  wiresaw2           QEP from vibration analysis of wiresaw with viscous
%                     damping effect.
%
%  Examples:
%  coeffs = nlevp('railtrack')
%    generates the matrices defining the railtrack problem.
%  nlevp('help','railtrack')
%    prints the help text of the railtrack problem.
%  nlevp('query','railtrack')
%    prints the properties of the railtrack problem.
%
%  For example code to solve all polynomial eigenvalue problems (PEPs)
%  in this collection of dimension < 500 with MATLAB's POLYEIG
%  see NLEVP_EXAMPLE.M.

%  Reference:
%  T. Betcke, N. J. Higham, V. Mehrmann, C. Schroeder, and F. Tisseur.
%  NLEVP: A Collection of Nonlinear Eigenvalue Problems,
%  MIMS EPrint 2008.40, Manchester Institute for Mathematical Sciences,
%  The University of Manchester, UK, 2008.

% Check inputs
if nargin < 1, error('Not enough input arguments'); end
if ~ischar(name), error('NAME must be a string'); end

if strcmpi(name,'query') && nargin == 1
   error('Not enough input arguments')
end

switch lower(name)
    case 'help'
        if nargin < 2, error('Not enough input parameters'); end
        name = varargin{1};
        if ~ischar(name), error('NAME must be a string'); end
        eval(['help ', name]);
        return
    otherwise
        [varargout{1:nargout}] = feval(name,varargin{:});
end
