function coeffs = acoustic_wave_1d(n,z)
%ACOUSTIC_WAVE_1D   Acoustic wave problem in 1 dimension.
%  COEFFS = NLEVP('acoustic_wave_1d',N,Z) constructs an N-by-N
%  quadratic matrix polynomial lambda^2*M + lambda*D + K that arises
%  from the discretization of a 1D acoustic wave equation.
%  The damping matrix has the form Z^(-1)*D, where
%  D is a low rank real symmetric matrix and the scalar parameter Z is
%  the impedance (posibly complex).
%  The default values are N = 10 and Z = 1.
%  The matrices are returned in a cell array: COEFFS = {K, D, M}.
%  This problem has the properties pep, qep, real, symmetric,
%  parameter-dependent, scalable.

%  Reference:
%  F. Chaitin-Chatelin and M. B. van Gijzen, Analysis of parameterized
%  quadratic eigenvalue problems in computational acoustics with homotopic
%  deviation theory, Numer. Linear Algebra Appl. 13 (2006), pp. 487--512

if nargin < 2 || isempty(z), z = 1; end;
if nargin < 1 || isempty(n), n = 10; end;

h = 1/n;
K = diag(2*ones(n,1)) - diag(ones(n-1,1),-1) - diag(ones(n-1,1),+1);
K(n,n) = 1;
K = n*K;

D = zeros(n); D(n,n) = 1/z;
M = eye(n); M(n,n) = 0.5; M = h*M;

coeffs = {K, D, M};
