function coeffs = loaded_string(n,kappa)
%LOADED_STRING    REP from finite element model of a loaded vibrating string.
%   COEFFS = NLEVP('loaded_string',N,KAPPA) generates an N-by-N rational
%   matrix function A - lambda*B + lambda/(lambda-sigma)*C with sigma = KAPPA/m
%   arising in the finite element discretization of a boundary problem
%   describing the eigenvibration of a string with a load of mass m
%   attached by an elastic spring of stiffness KAPPA.
%   The default values are N = 20, KAPPA = 1.
%   The matrices are returned in a cell array: COEFFS = {A, B, C}.
%   This problem has the properties rep, qep, real, symmetric,
%   parameter_dependent, scalable.

%   Reference:
%   S. I. Solov"ev. Preconditioned iterative methods for a class of nonlinear
%   eigenvalue problems. Linear Algebra Appl., 415 (2006), pp.210-229.

if nargin < 2 || isempty(kappa), kappa = 1; end;
if nargin < 1 || isempty(n), n = 20; end;

A = toeplitz([2,-1,zeros(1,n-2)]); A(n,n) = 1;
B = toeplitz([4,1,zeros(1,n-2)]); B(n,n) = 2;
C = zeros(n); C(n,n) = 1;

coeffs = {n*A, 1/(6*n)*B, kappa*C};
