function coeffs = sign1(n,a)
%SIGN1  QEP from rank-1 perturbation of sign operator.
%  COEFFS = NLEVP('sign1',N,MU) generates the coefficient matrices of
%  a quadratic matrix polynomial lambda^2*A + lambda*B + C of dimension
%  2*N+1.  The spectrum of this matrix polynomial is the second order
%  spectrum of a rank one perturbation of the operator of multiplication
%  by the function sign(x) acting in L^2(-\pi,\pi), with respect to
%  the Fourier basis: e^{-iNx},\ldots,1,\ldots e^{iNx}.
%  The strength of the perturbation is the real parameter MU.
%  By default N = 40 and MU = 0.
%  The matrices are returned in a cell array: COEFFS = {C, B, A}.
%  This problem has the properties qep, hermitian, parameter-dependent,
%  scalable.

%  Reference:
%  L. Boulton, Non-variational approximation of discrete eigenvalues of
%  self-adjoint operators, IMA J. Numer. Anal. 27 (2007), pp. 102-121.

if nargin < 1 || isempty(n), n = 40; end
if nargin < 2, a = 0; end

% Fourier coeff. of the symbol.
fc = zeros(2*n+1,2);
fc(1,2) = 1;                       % FC of the square of the operator
for k=2:2:2*n
    fc(k,1) = i*2/(pi*(k-1));      % FC of the operator
end;

% Matrix truncations
K = zeros(2*n+1);
K(n+1,n+1) = a;
MK = zeros(2*n+1);
B = toeplitz(fc(1:2*n+1,1));
MK(:,n+1) = B(:,n+1);
Q = toeplitz(fc(1:2*n+1,2));
A0 = Q + a*MK + a*MK' + K^2;
A1 = -2*(B+K);
A2 = eye(2*n+1);
coeffs = {A0, A1, A2};
