function coeffs = spring_dashpot(rho,m,state)
%SPRING_DASHPOT  QEP from model of spring/dashpot configuration.
%  COEFFS = NLEVP('spring_dashpot', RHO, M, S) generates a 2*(M+1)-by-2*(M+1)
%  quadratic matrix polynomial Q(lambda) = lambda^2*M + lambda*D + K
%  arising from the modelling of a linear spring in parallel with
%  M Maxwell elements, where a Maxwell element is a spring in series
%  with a dashpot.  RHO is the material density.
%  This example reflects the structure only, since the matrices themselves
%  are not from a finite element model but randomly generated to have
%  the desired properties of symmetry etc.
%  S (default: S = 0) is used in the function call RAND('twister',S) to
%  set the random number generator (see HELP RAND).
%  The singular mass matrix M contributes infinite eigenvalues.
%  By default, M = 4 and RHO = 7850.
%  Properties of the coefficient matrices:
%     M is rank deficient and symmetric.
%     D is rank deficient and block diagonal.
%     K is symmetric and has arrowhead structure.
%  The matrices are returned in a cell array: coeffs = {K, D, M}.
%  This problem has the properties qep, pep, real, parameter-dependent,
%  scalable.

%  Reference:
%  Anthony Gotts, Report regarding model reduction, model compaction
%  project, University of Nottingham, Feb. 2005.

% Default is steel for rho, the material density.
if nargin < 1 || isempty(rho), rho = 7850; end;
if nargin < 2 || isempty(m), m = 4; end;
if nargin < 3 || isempty(state), state = 0; end;

rand('twister',state) % Set state for random numbers.

% Generate one random element stiffness matrix and reuse.
K = rand(2); K = K*K';

% Generate one random element mass matrix and reuse.
M = rand(2); M = M*M';
e = rand(1,m);
eta = rand(1,m);
alpha_rho = sum(e);

B = kron(eta, K);
M = blkdiag(rho*M, zeros(2*m));
D = kron(blkdiag(0,diag(eta)),K);
K = kron(blkdiag(alpha_rho,diag(e)), K) + [zeros(2) B; B' zeros(2*m)];

coeffs{3} = M;
coeffs{2} = D;
coeffs{1} = K;
