function coeffs = string(n,m,tau,kappa)
%STRING    QEP from finite element model of vibrating string.
%  COEFFS = NLEVP('string',N,MU,TAU,KAPPA) generates an N-by-N
%  quadratic matrix polynomial lambda^2*M + lambda*D + K arising
%  in the vibration analysis of a linearly damped string.
%  MU is the mass, TAU is proportional to the damping constants and
%  K is proportional to the spring constants of the system.
%  MU, TAU and KAPPA are nonnegative.
%  The default values are N = 5, MU = 1, TAU = 10, KAPPA = 5.
%  The matrices are returned in a cell array: coeffs = {K, D, M}.
%  This problem has the properties pep, qep, real, symmetric,
%  proportionally-damped, parameter_dependent, scalable.

%  Reference:
%  F. Tisseur, Backward error and condition of polynomial
%  eigenvalue problems. Linear Algebra and Appl. 309 (2000), pp. 339-361.

if nargin < 4 || isempty(kappa), kappa = 5; end;
if nargin < 3 || isempty(tau), tau = 10; end;
if nargin < 2 || isempty(m), mu = 1; end;
if nargin < 1 || isempty(n), n = 5; end;

L = toeplitz([3,-1,zeros(1,n-2)]);

coeffs = {kappa*L, tau*L, mu*eye(n)};
